@@ -69,8 +69,8 @@ AltTabPopupW.prototype = {
     __proto__ : AltTab.AltTabPopup.prototype,
 
     show : function(backward, switch_group) {
-        let tracker = Shell.WindowTracker.get_default();
-        let apps = tracker.get_running_apps ('');
+        let appSys = Shell.AppSystem.get_default();
+        let apps = appSys.get_running ();
 
         if (!apps.length)
             return false;
@@ -358,8 +358,8 @@ AltTabPopup2.prototype = {
 	let list = '';
 	let normal_windows= [];
 	let appIcons = [];
-	let tracker = Shell.WindowTracker.get_default();
-	let apps = tracker.get_running_apps ('');
+	let appSys = Shell.AppSystem.get_default();
+	let apps = appSys.get_running();
 
 	for (let w = windows.length-1; w >= 0; w--) {
 	    let win = windows[w].get_meta_window();
@@ -507,8 +507,8 @@ WindowList.prototype = {
 
 	    let win=windows[w];
 
-	    let tracker = Shell.WindowTracker.get_default();
-	    let apps = tracker.get_running_apps ('');
+	    let appSys = Shell.AppSystem.get_default();
+	    let apps = appSys.get_running();
 	    let ap1 = null;
 	    for (let i = 0; i < apps.length; i++) {
 	        let app_wins = apps[i].get_windows();
@@ -541,19 +541,33 @@ WindowList.prototype = {
     }
 };
 
-function main(metadata) {
+function init(metadata) {
     imports.gettext.bindtextdomain('gnome-shell-extensions', metadata.localedir);
-
-    Main.wm.setKeybindingHandler('switch_windows', function() {
-        let settings = new Gio.Settings({ schema: SETTINGS_SCHEMA });
-
-        if(settings.get_boolean(SETTINGS_FIRST_TIME_KEY)) {
-           new AltTabSettingsDialog().open();
-        } else {
-            let behaviour = settings.get_string(SETTINGS_BEHAVIOUR_KEY);
-            if(behaviour in MODES) {
-                MODES[behaviour]();
-            }
-        }
-    });
 }
+
+function doAltTab(shellwm, binding, window, backwards) {
+    let settings = new Gio.Settings({ schema: SETTINGS_SCHEMA });
+
+    if(settings.get_boolean(SETTINGS_FIRST_TIME_KEY)) {
+        new AltTabSettingsDialog().open();
+    } else {
+        let behaviour = settings.get_string(SETTINGS_BEHAVIOUR_KEY);
+        if(behaviour in MODES) {
+            MODES[behaviour](binding, backwards);
+        }
+    }
+}
+
+function enable() {
+    Main.wm.setKeybindingHandler('switch_windows', doAltTab);
+    Main.wm.setKeybindingHandler('switch_group', doAltTab);
+    Main.wm.setKeybindingHandler('switch_windows_backward', doAltTab);
+    Main.wm.setKeybindingHandler('switch_group_backward', doAltTab);
+}
+
+function disable() {
+    Main.wm.setKeybindingHandler('switch_windows', Lang.bind(Main.wm, Main.wm._startAppSwitcher));
+    Main.wm.setKeybindingHandler('switch_group', Lang.bind(Main.wm, Main.wm._startAppSwitcher));
+    Main.wm.setKeybindingHandler('switch_windows_backward', Lang.bind(Main.wm, Main.wm._startAppSwitcher));
+    Main.wm.setKeybindingHandler('switch_group_backward', Lang.bind(Main.wm, Main.wm._startAppSwitcher));
+}
\ No newline at end of file
